/*
 * This file is part of afw.
 *
 * Developed for the LSST Data Management System.
 * This product includes software developed by the LSST Project
 * (https://www.lsst.org).
 * See the COPYRIGHT file at the top-level directory of this distribution
 * for details of code ownership.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <pybind11/pybind11.h>
#include <lsst/utils/python.h>

#include "lsst/afw/geom/ellipses/ReducedShear.h"
#include "lsst/afw/geom/ellipses/EllipticityBase.h"

namespace py = pybind11;

using namespace py::literals;

namespace lsst {
namespace afw {
namespace geom {
namespace ellipses {
void wrapReducedShear(lsst::utils::python::WrapperCollection &wrappers) {
    wrappers.wrapType(py::class_<ReducedShear, detail::EllipticityBase>(wrappers.module, "ReducedShear"),
                      [](auto &mod, auto &cls) {
                          /* Constructors */
                          cls.def(py::init<std::complex<double> const &>());
                          cls.def(py::init<double, double>(), "e1"_a = 0.0, "e2"_a = 0.0);

                          /* Members */
                          //    cls.def("dAssign", (Jacobian (ReducedShear::*)(Distortion const &))
                          //    &ReducedShear::dAssign); cls.def("dAssign", (Jacobian
                          //    (ReducedShear::*)(ReducedShear const &)) &ReducedShear::dAssign);
                          cls.def("getAxisRatio", &ReducedShear::getAxisRatio);
                          cls.def("normalize", &ReducedShear::normalize);
                          cls.def("getName", &ReducedShear::getName);
                          cls.def("__repr__", [](ReducedShear const &self) {
                              return py::str("{}({}, {})").format(self.getName(), self.getE1(), self.getE2());
                          });
                      });
}
}  // namespace ellipses
}  // namespace geom
}  // namespace afw
}  // namespace lsst